/****************************************************************************
** Meta object code from reading C++ file 'declarativetheme_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtdatavis3d/src/datavisualizationqml/declarativetheme_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativetheme_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DeclarativeTheme3DE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeTheme3D::qt_create_metaobjectdata<qt_meta_tag_ZN18DeclarativeTheme3DE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeTheme3D",
        "DefaultProperty",
        "themeChildren",
        "QML.Element",
        "Theme3D",
        "QML.AddedInVersion",
        "256",
        "singleHighlightGradientChanged",
        "",
        "ColorGradient*",
        "gradient",
        "multiHighlightGradientChanged",
        "QQmlListProperty<QObject>",
        "baseColors",
        "QQmlListProperty<DeclarativeColor>",
        "baseGradients",
        "QQmlListProperty<ColorGradient>",
        "singleHighlightGradient",
        "multiHighlightGradient"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'singleHighlightGradientChanged'
        QtMocHelpers::SignalData<void(ColorGradient *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'multiHighlightGradientChanged'
        QtMocHelpers::SignalData<void(ColorGradient *)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'themeChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'baseColors'
        QtMocHelpers::PropertyData<QQmlListProperty<DeclarativeColor>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'baseGradients'
        QtMocHelpers::PropertyData<QQmlListProperty<ColorGradient>>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'singleHighlightGradient'
        QtMocHelpers::PropertyData<ColorGradient*>(17, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'multiHighlightGradient'
        QtMocHelpers::PropertyData<ColorGradient*>(18, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeTheme3D, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeTheme3D::staticMetaObject = { {
    QMetaObject::SuperData::link<Q3DTheme::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeTheme3DE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeTheme3DE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DeclarativeTheme3DE_t>.metaTypes,
    nullptr
} };

void DeclarativeTheme3D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeTheme3D *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->singleHighlightGradientChanged((*reinterpret_cast<std::add_pointer_t<ColorGradient*>>(_a[1]))); break;
        case 1: _t->multiHighlightGradientChanged((*reinterpret_cast<std::add_pointer_t<ColorGradient*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ColorGradient* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ColorGradient* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeTheme3D::*)(ColorGradient * )>(_a, &DeclarativeTheme3D::singleHighlightGradientChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeTheme3D::*)(ColorGradient * )>(_a, &DeclarativeTheme3D::multiHighlightGradientChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ColorGradient* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->themeChildren(); break;
        case 1: *reinterpret_cast<QQmlListProperty<DeclarativeColor>*>(_v) = _t->baseColors(); break;
        case 2: *reinterpret_cast<QQmlListProperty<ColorGradient>*>(_v) = _t->baseGradients(); break;
        case 3: *reinterpret_cast<ColorGradient**>(_v) = _t->singleHighlightGradient(); break;
        case 4: *reinterpret_cast<ColorGradient**>(_v) = _t->multiHighlightGradient(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setSingleHighlightGradient(*reinterpret_cast<ColorGradient**>(_v)); break;
        case 4: _t->setMultiHighlightGradient(*reinterpret_cast<ColorGradient**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeTheme3D::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeTheme3D::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeTheme3DE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return Q3DTheme::qt_metacast(_clname);
}

int DeclarativeTheme3D::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Q3DTheme::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeTheme3D::singleHighlightGradientChanged(ColorGradient * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeTheme3D::multiHighlightGradientChanged(ColorGradient * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
