/****************************************************************************
** Meta object code from reading C++ file 'q3dscatter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtdatavis3d/src/datavisualization/engine/q3dscatter.h"
#include <QtDataVisualization/q3dscene.h>
#include <QtDataVisualization/qscatter3dseries.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'q3dscatter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10Q3DScatterE_t {};
} // unnamed namespace

template <> constexpr inline auto Q3DScatter::qt_create_metaobjectdata<qt_meta_tag_ZN10Q3DScatterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Q3DScatter",
        "axisXChanged",
        "",
        "QValue3DAxis*",
        "axis",
        "axisYChanged",
        "axisZChanged",
        "selectedSeriesChanged",
        "QScatter3DSeries*",
        "series",
        "axisX",
        "axisY",
        "axisZ",
        "selectedSeries"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'axisZChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'selectedSeriesChanged'
        QtMocHelpers::SignalData<void(QScatter3DSeries *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QValue3DAxis*>(10, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'axisY'
        QtMocHelpers::PropertyData<QValue3DAxis*>(11, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'axisZ'
        QtMocHelpers::PropertyData<QValue3DAxis*>(12, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'selectedSeries'
        QtMocHelpers::PropertyData<QScatter3DSeries*>(13, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Q3DScatter, qt_meta_tag_ZN10Q3DScatterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Q3DScatter::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstract3DGraph::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Q3DScatterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Q3DScatterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Q3DScatterE_t>.metaTypes,
    nullptr
} };

void Q3DScatter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Q3DScatter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 2: _t->axisZChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 3: _t->selectedSeriesChanged((*reinterpret_cast<std::add_pointer_t<QScatter3DSeries*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScatter3DSeries* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Q3DScatter::*)(QValue3DAxis * )>(_a, &Q3DScatter::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Q3DScatter::*)(QValue3DAxis * )>(_a, &Q3DScatter::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Q3DScatter::*)(QValue3DAxis * )>(_a, &Q3DScatter::axisZChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Q3DScatter::*)(QScatter3DSeries * )>(_a, &Q3DScatter::selectedSeriesChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScatter3DSeries* >(); break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QValue3DAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QValue3DAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QValue3DAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QValue3DAxis**>(_v) = _t->axisZ(); break;
        case 3: *reinterpret_cast<QScatter3DSeries**>(_v) = _t->selectedSeries(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        case 2: _t->setAxisZ(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Q3DScatter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Q3DScatter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Q3DScatterE_t>.strings))
        return static_cast<void*>(this);
    return QAbstract3DGraph::qt_metacast(_clname);
}

int Q3DScatter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstract3DGraph::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Q3DScatter::axisXChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Q3DScatter::axisYChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Q3DScatter::axisZChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Q3DScatter::selectedSeriesChanged(QScatter3DSeries * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
